@@ -10,6 +10,16 @@ def download(pdb_id, file_type, out_dir):
     res = requests.get(url)
     outfile = "{out_dir}/{pdb_id}.{type}.gz".format(pdb_id=pdb_id, type=file_type, out_dir=out_dir)
     open(outfile, "wb").write(res.content)
+    import gzip
+    import shutil
+    zipfile = outfile
+    output_file = zipfile[:-3]
+    with gzip.open(zipfile, 'rb') as f_in:
+        with open(output_file, 'wb') as f_out:
+            shutil.copyfileobj(f_in, f_out)
+
+    import os
+    os.remove(outfile)
 
 
 def download_list_pdb(pdb_list, type_list, out_dir):
@@ -19,10 +29,9 @@ def download_list_pdb(pdb_list, type_list, out_dir):
         for tp in type_list:
             download(pdb, tp, out_dir)
 
-def get_pdb_parser(pdb_name,pdb_file):
+
+def get_pdb_parser(pdb_name, pdb_file):
     from Bio.PDB import PDBParser
     return PDBParser().get_structure(pdb_name, pdb_file)
 
-
-
 # download_list_pdb(["7niu_A", "6s7p_A"], ["pdb", "pdb1", "xml"],"./data")
